@@ -17,7 +17,16 @@ class Windows2008R2Only(object):
 
     def __call__(self, *args, **kwargs):
         if not is_windows_2008_r2():
-            raise NotImplementedError
+            raise NotImplementedError()
+        return self.func(*args, **kwargs)
+
+class Windows2008Only(object):
+    def __init__(self, func):
+        self.func = func
+
+    def __call__(self, *args, **kwargs):
+        if not is_windows_2008():
+            raise NotImplementedError()
         return self.func(*args, **kwargs)
 
 CLEAR_POLICY = 0
@@ -146,7 +155,7 @@ class MultipathClaim(object):
             return LEAST_BLOCKS
 
     @classmethod
-    @Windows2008R2Only
+    @Windows2008Only
     def get_default_load_balancing_policy(cls):
         """ returns MSDSM's default load balancing policy
         """
@@ -154,14 +163,14 @@ class MultipathClaim(object):
         return cls._extract_load_balancing_from_output(output)
 
     @classmethod
-    @Windows2008R2Only
+    @Windows2008Only
     def set_default_load_balancing_policy(cls, policy):
         """ sets MSDSM's default load balancing policy
         """
         cls.execute(["-l", "-m", str(policy)])
 
     @classmethod
-    @Windows2008R2Only
+    @Windows2008Only
     def get_hardware_specific_load_balancing_poicy(cls, vendor_id, product_id):
         """ gets MSDSM's explicit load balancing policy for a given hardware type
         if no such policy exists, CLEAR_POLICY is returns, and NOT the global-wise policy
@@ -171,14 +180,14 @@ class MultipathClaim(object):
         return cls._extract_hardware_specific_load_balacing_policy(output, hardware_id)
 
     @classmethod
-    @Windows2008R2Only
+    @Windows2008Only
     def set_hardware_specific_load_balancing_policy(cls, vendor_id, product_id, policy):
         """ sets a load balancing policy explicitly for a given hardware type
         """
         cls.execute(["-l", "-t", cls._get_hardware_id(vendor_id, product_id), str(policy)])
 
     @classmethod
-    @Windows2008R2Only
+    @Windows2008Only
     def set_device_specific_load_balancing_policy(cls, device, load_balance_policy):
         """ sets an explicit load balancing policy for a given device
         this method accepts a Device and LoadBalancePolicy objects, and sets
