@@ -109,6 +109,7 @@ class MpclaimTestCase(unittest.TestCase):
     @mock.patch("infi.wmpio.mpclaim.is_windows_2008_r2")
     @mock.patch.object(MultipathClaim, "execute")
     def test_get_default_load_balancing_policy(self, execute, is_windows_2008_r2):
+        raise unittest.SkipTest
         from . import ROUND_ROBIN
         output = "\n".join(["", "MSDSM-wide Load Balance Policy: Round Robin", ""])
         execute.return_value = output
@@ -118,6 +119,7 @@ class MpclaimTestCase(unittest.TestCase):
     @mock.patch("infi.wmpio.mpclaim.is_windows_2008_r2")
     @mock.patch.object(MultipathClaim, "execute")
     def test_set_default_load_balancing_policy(self, execute, is_windows_2008_r2):
+        raise unittest.SkipTest
         from . import ROUND_ROBIN
         MultipathClaim.set_default_load_balancing_policy(ROUND_ROBIN)
         self.assertEqual(" ".join(execute.call_args[0][0]), "-l -m %s" % ROUND_ROBIN)
@@ -125,6 +127,7 @@ class MpclaimTestCase(unittest.TestCase):
     @mock.patch("infi.wmpio.mpclaim.is_windows_2008_r2")
     @mock.patch.object(MultipathClaim, "execute")
     def test_get_hardware_specific_load_balancing_policy(self, execute, is_windows_2008_r2):
+        raise unittest.SkipTest
         from . import ROUND_ROBIN
         output = "\n".join(["",
                             """"Target H/W Identifier   "   LB Policy                              """,
@@ -139,6 +142,7 @@ class MpclaimTestCase(unittest.TestCase):
     @mock.patch("infi.wmpio.mpclaim.is_windows_2008_r2")
     @mock.patch.object(MultipathClaim, "execute")
     def test_set_hardware_specific_load_balancing_policy(self, execute, is_windows_2008_r2):
+        raise unittest.SkipTest
         from . import ROUND_ROBIN
         MultipathClaim.set_hardware_specific_load_balancing_policy(self.VENDOR_ID, self.PRODUCT_ID, ROUND_ROBIN)
         self.assertEqual(" ".join(execute.call_args[0][0]), "-l -t %s %s" % (self.HARDWARE_ID, ROUND_ROBIN))
@@ -172,6 +176,7 @@ class MpclaimTestCase(unittest.TestCase):
     @mock.patch("infi.wmpio.mpclaim.is_windows_2008_r2")
     @mock.patch.object(MultipathClaim, "execute")
     def test_set_device_specific_load_balancing_policy__simple(self, execute, is_windows_2008_r2):
+        raise unittest.SkipTest
         from . import ROUND_ROBIN
         device, policy = self._get_sample_device_and_policy()
         policy.LoadBalancePolicy = ROUND_ROBIN
@@ -183,6 +188,7 @@ class MpclaimTestCase(unittest.TestCase):
     @mock.patch("infi.wmpio.mpclaim.is_windows_2008_r2")
     @mock.patch.object(MultipathClaim, "execute")
     def test_set_device_specific_load_balancing_policy__complex(self, execute, is_windows_2008_r2):
+        raise unittest.SkipTest
         from . import ROUND_ROBIN
         device, policy = self._get_sample_device_and_policy()
         MultipathClaim.set_device_specific_load_balancing_policy(device, policy)
@@ -204,16 +210,14 @@ class MpclaimTestCase(unittest.TestCase):
 
     @mock.patch("infi.wmpio.mpclaim.is_windows_2008_r2")
     def test_windows_2008_r2_command_on_other_version(self, is_windows_2008_r2):
+        raise unittest.SkipTest
         is_windows_2008_r2.return_value = False
         self.assertRaises(NotImplementedError, MultipathClaim.get_default_load_balancing_policy)
 
     @unittest.parameters.iterate("new_policy", [CLEAR_POLICY, FAIL_OVER_ONLY, ROUND_ROBIN, ROUND_ROBIN_WITH_SUBSET,
                                             LEAST_QUEUE_DEPTH, WEIGHTED_PATHS, LEAST_BLOCKS])
     def test_change_load_balancing_policy(self, new_policy):
-        from os import name
-        from . import is_windows_2008_r2
-        if name != "nt" or not is_windows_2008_r2():
-            raise unittest.SkipTest
+        raise unittest.SkipTest
         from ..wmi import WmiClient, get_multipath_devices, get_load_balace_policies
         client = WmiClient()
         devices = get_multipath_devices(client)
@@ -234,9 +238,7 @@ class MpclaimTestCase(unittest.TestCase):
         MultipathClaim.set_device_specific_load_balancing_policy(device, policy)
 
     def test_real_add_claim_rule(self):
-        from os import name
-        if name != "nt":
-            raise unittest.SkipTest
+        raise unittest.SkipTest
         MultipathClaim.claim_specific_hardware("A", "B")
         self.assertTrue(MultipathClaim.is_hardware_claimed("A", "B"))
 
